@@ -1,20 +1,16 @@
 # var list
-variables = gl.project_variables.list(project_id=1)
-# or
-variables = project.variables.list()
+p_variables = project.variables.list()
+g_variables = group.variables.list()
 # end var list
 
 # var get
-var = gl.project_variables.get(var_key, project_id=1)
-# or
-var = project.variables.get(var_key)
+p_var = project.variables.get(var_key)
+g_var = group.variables.get(var_key)
 # end var get
 
 # var create
-var = gl.project_variables.create({'key': 'key1', 'value': 'value1'},
-                                  project_id=1)
-# or
 var = project.variables.create({'key': 'key1', 'value': 'value1'})
+var = group.variables.create({'key': 'key1', 'value': 'value1'})
 # end var create
 
 # var update
@@ -23,58 +19,48 @@ var.save()
 # end var update
 
 # var delete
-gl.project_variables.delete(var_key)
-# or
-project.variables.delete()
+project.variables.delete(var_key)
+group.variables.delete(var_key)
 # or
 var.delete()
 # end var delete
 
 # trigger list
-triggers = gl.project_triggers.list(project_id=1)
-# or
 triggers = project.triggers.list()
 # end trigger list
 
 # trigger get
-trigger = gl.project_triggers.get(trigger_token, project_id=1)
-# or
 trigger = project.triggers.get(trigger_token)
 # end trigger get
 
 # trigger create
-trigger = gl.project_triggers.create({}, project_id=1)
-# or
 trigger = project.triggers.create({})
 # end trigger create
 
 # trigger delete
-gl.project_triggers.delete(trigger_token)
-# or
-project.triggers.delete()
+project.triggers.delete(trigger_token)
 # or
 trigger.delete()
 # end trigger delete
 
 # list
-builds = gl.project_builds.list(project_id=1)
-# or
-builds = project.builds.list()
+builds = project.builds.list()  # v3
+jobs = project.jobs.list()  # v4
 # end list
 
 # commit list
+# v3 only
 commit = gl.project_commits.get(commit_sha, project_id=1)
 builds = commit.builds()
 # end commit list
 
 # get
-build = gl.project_builds.get(build_id, project_id=1)
-# or
-project.builds.get(build_id)
+project.builds.get(build_id)  # v3
+project.jobs.get(job_id)  # v4
 # end get
 
 # artifacts
-build.artifacts()
+build_or_job.artifacts()
 # end artifacts
 
 # stream artifacts
@@ -86,33 +72,32 @@ class Foo(object):
         self._fd.write(chunk)
 
 target = Foo()
-build.artifacts(streamed=True, action=target)
+build_or_job.artifacts(streamed=True, action=target)
 del(target)  # flushes data on disk
 # end stream artifacts
 
 # keep artifacts
-build.keep_artifacts()
+build_or_job.keep_artifacts()
 # end keep artifacts
 
 # trace
-build.trace()
+build_or_job.trace()
 # end trace
 
 # retry
-build.cancel()
-build.retry()
+build_or_job.cancel()
+build_or_job.retry()
 # end retry
 
 # erase
-build.erase()
+build_or_job.erase()
 # end erase
 
 # play
-build.play()
+build_or_job.play()
 # end play
 
 # trigger run
-p = gl.projects.get(project_id)
-p.trigger_build('master', trigger_token,
-                {'extra_var1': 'foo', 'extra_var2': 'bar'})
+project.trigger_build('master', trigger_token,
+                      {'extra_var1': 'foo', 'extra_var2': 'bar'})
 # end trigger run
