@@ -1213,6 +1213,12 @@ class ProjectMergeRequestManager(CRUDMixin, RESTManager):
                                'milestone_id'))
     _list_filters = ('iids', 'state', 'order_by', 'sort')
 
+    def _sanitize_data(self, data, action):
+        new_data = data.copy()
+        if 'labels' in data:
+            new_data['labels'] = ','.join(data['labels'])
+        return new_data
+
 
 class ProjectMilestone(SaveMixin, ObjectDeleteMixin, RESTObject):
     _short_print_attr = 'title'
@@ -1354,6 +1360,7 @@ class ProjectFile(SaveMixin, ObjectDeleteMixin, RESTObject):
         """
         self.branch = branch
         self.commit_message = commit_message
+        self.file_path = self.file_path.replace('/', '%2F')
         super(ProjectFile, self).save(**kwargs)
 
     def delete(self, branch, commit_message, **kwargs):
@@ -1368,7 +1375,8 @@ class ProjectFile(SaveMixin, ObjectDeleteMixin, RESTObject):
             GitlabAuthenticationError: If authentication is not correct
             GitlabDeleteError: If the server cannot perform the request
         """
-        self.manager.delete(self.get_id(), branch, commit_message, **kwargs)
+        file_path = self.get_id().replace('/', '%2F')
+        self.manager.delete(file_path, branch, commit_message, **kwargs)
 
 
 class ProjectFileManager(GetMixin, CreateMixin, UpdateMixin, DeleteMixin,
